from typing import Any

POSIX: int
UNICODE: int
VERBOSE: int

def compile(pattern, flags=0, **kwargs) -> Any:
    ...
